"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest
from datetime import datetime, date
import pytest

import freeclimb

from freeclimb.model.request_type import RequestType  # noqa: E501

class TestRequestType(unittest.TestCase):
    """RequestType unit test stubs"""

    
    def test_INBOUND_CALL_should_serialize_to_enum(self):
        expected = RequestType.INBOUND_CALL
        calculated = RequestType['INBOUND_CALL']
        assert expected == calculated

    def test_INBOUND_CALL_should_deserialize_to_string(self):
        test = RequestType.INBOUND_CALL
        expected = "inboundCall"
        calculated = test.value
        assert expected == calculated

    def test_RECORD_should_serialize_to_enum(self):
        expected = RequestType.RECORD
        calculated = RequestType['RECORD']
        assert expected == calculated

    def test_RECORD_should_deserialize_to_string(self):
        test = RequestType.RECORD
        expected = "record"
        calculated = test.value
        assert expected == calculated

    def test_GET_DIGITS_should_serialize_to_enum(self):
        expected = RequestType.GET_DIGITS
        calculated = RequestType['GET_DIGITS']
        assert expected == calculated

    def test_GET_DIGITS_should_deserialize_to_string(self):
        test = RequestType.GET_DIGITS
        expected = "getDigits"
        calculated = test.value
        assert expected == calculated

    def test_GET_SPEECH_should_serialize_to_enum(self):
        expected = RequestType.GET_SPEECH
        calculated = RequestType['GET_SPEECH']
        assert expected == calculated

    def test_GET_SPEECH_should_deserialize_to_string(self):
        test = RequestType.GET_SPEECH
        expected = "getSpeech"
        calculated = test.value
        assert expected == calculated

    def test_REDIRECT_should_serialize_to_enum(self):
        expected = RequestType.REDIRECT
        calculated = RequestType['REDIRECT']
        assert expected == calculated

    def test_REDIRECT_should_deserialize_to_string(self):
        test = RequestType.REDIRECT
        expected = "redirect"
        calculated = test.value
        assert expected == calculated

    def test_PAUSE_should_serialize_to_enum(self):
        expected = RequestType.PAUSE
        calculated = RequestType['PAUSE']
        assert expected == calculated

    def test_PAUSE_should_deserialize_to_string(self):
        test = RequestType.PAUSE
        expected = "pause"
        calculated = test.value
        assert expected == calculated

    def test_OUT_DIAL_START_should_serialize_to_enum(self):
        expected = RequestType.OUT_DIAL_START
        calculated = RequestType['OUT_DIAL_START']
        assert expected == calculated

    def test_OUT_DIAL_START_should_deserialize_to_string(self):
        test = RequestType.OUT_DIAL_START
        expected = "outDialStart"
        calculated = test.value
        assert expected == calculated

    def test_OUT_DIAL_CONNECT_should_serialize_to_enum(self):
        expected = RequestType.OUT_DIAL_CONNECT
        calculated = RequestType['OUT_DIAL_CONNECT']
        assert expected == calculated

    def test_OUT_DIAL_CONNECT_should_deserialize_to_string(self):
        test = RequestType.OUT_DIAL_CONNECT
        expected = "outDialConnect"
        calculated = test.value
        assert expected == calculated

    def test_OUT_DIAL_API_CONNECT_should_serialize_to_enum(self):
        expected = RequestType.OUT_DIAL_API_CONNECT
        calculated = RequestType['OUT_DIAL_API_CONNECT']
        assert expected == calculated

    def test_OUT_DIAL_API_CONNECT_should_deserialize_to_string(self):
        test = RequestType.OUT_DIAL_API_CONNECT
        expected = "outDialApiConnect"
        calculated = test.value
        assert expected == calculated

    def test_MACHINE_DETECTED_should_serialize_to_enum(self):
        expected = RequestType.MACHINE_DETECTED
        calculated = RequestType['MACHINE_DETECTED']
        assert expected == calculated

    def test_MACHINE_DETECTED_should_deserialize_to_string(self):
        test = RequestType.MACHINE_DETECTED
        expected = "machineDetected"
        calculated = test.value
        assert expected == calculated

    def test_DEQUEUE_should_serialize_to_enum(self):
        expected = RequestType.DEQUEUE
        calculated = RequestType['DEQUEUE']
        assert expected == calculated

    def test_DEQUEUE_should_deserialize_to_string(self):
        test = RequestType.DEQUEUE
        expected = "dequeue"
        calculated = test.value
        assert expected == calculated

    def test_QUEUE_WAIT_should_serialize_to_enum(self):
        expected = RequestType.QUEUE_WAIT
        calculated = RequestType['QUEUE_WAIT']
        assert expected == calculated

    def test_QUEUE_WAIT_should_deserialize_to_string(self):
        test = RequestType.QUEUE_WAIT
        expected = "queueWait"
        calculated = test.value
        assert expected == calculated

    def test_ADD_TO_QUEUE_NOTIFICATION_should_serialize_to_enum(self):
        expected = RequestType.ADD_TO_QUEUE_NOTIFICATION
        calculated = RequestType['ADD_TO_QUEUE_NOTIFICATION']
        assert expected == calculated

    def test_ADD_TO_QUEUE_NOTIFICATION_should_deserialize_to_string(self):
        test = RequestType.ADD_TO_QUEUE_NOTIFICATION
        expected = "addToQueueNotification"
        calculated = test.value
        assert expected == calculated

    def test_REMOVE_FROM_QUEUE_NOTIFICATION_should_serialize_to_enum(self):
        expected = RequestType.REMOVE_FROM_QUEUE_NOTIFICATION
        calculated = RequestType['REMOVE_FROM_QUEUE_NOTIFICATION']
        assert expected == calculated

    def test_REMOVE_FROM_QUEUE_NOTIFICATION_should_deserialize_to_string(self):
        test = RequestType.REMOVE_FROM_QUEUE_NOTIFICATION
        expected = "removeFromQueueNotification"
        calculated = test.value
        assert expected == calculated

    def test_CALL_STATUS_should_serialize_to_enum(self):
        expected = RequestType.CALL_STATUS
        calculated = RequestType['CALL_STATUS']
        assert expected == calculated

    def test_CALL_STATUS_should_deserialize_to_string(self):
        test = RequestType.CALL_STATUS
        expected = "callStatus"
        calculated = test.value
        assert expected == calculated

    def test_CREATE_CONFERENCE_should_serialize_to_enum(self):
        expected = RequestType.CREATE_CONFERENCE
        calculated = RequestType['CREATE_CONFERENCE']
        assert expected == calculated

    def test_CREATE_CONFERENCE_should_deserialize_to_string(self):
        test = RequestType.CREATE_CONFERENCE
        expected = "createConference"
        calculated = test.value
        assert expected == calculated

    def test_CONFERENCE_STATUS_should_serialize_to_enum(self):
        expected = RequestType.CONFERENCE_STATUS
        calculated = RequestType['CONFERENCE_STATUS']
        assert expected == calculated

    def test_CONFERENCE_STATUS_should_deserialize_to_string(self):
        test = RequestType.CONFERENCE_STATUS
        expected = "conferenceStatus"
        calculated = test.value
        assert expected == calculated

    def test_LEAVE_CONFERENCE_should_serialize_to_enum(self):
        expected = RequestType.LEAVE_CONFERENCE
        calculated = RequestType['LEAVE_CONFERENCE']
        assert expected == calculated

    def test_LEAVE_CONFERENCE_should_deserialize_to_string(self):
        test = RequestType.LEAVE_CONFERENCE
        expected = "leaveConference"
        calculated = test.value
        assert expected == calculated

    def test_ADD_TO_CONFERENCE_NOTIFICATION_should_serialize_to_enum(self):
        expected = RequestType.ADD_TO_CONFERENCE_NOTIFICATION
        calculated = RequestType['ADD_TO_CONFERENCE_NOTIFICATION']
        assert expected == calculated

    def test_ADD_TO_CONFERENCE_NOTIFICATION_should_deserialize_to_string(self):
        test = RequestType.ADD_TO_CONFERENCE_NOTIFICATION
        expected = "addToConferenceNotification"
        calculated = test.value
        assert expected == calculated

    def test_CONFERENCE_RECORDING_STATUS_should_serialize_to_enum(self):
        expected = RequestType.CONFERENCE_RECORDING_STATUS
        calculated = RequestType['CONFERENCE_RECORDING_STATUS']
        assert expected == calculated

    def test_CONFERENCE_RECORDING_STATUS_should_deserialize_to_string(self):
        test = RequestType.CONFERENCE_RECORDING_STATUS
        expected = "conferenceRecordingStatus"
        calculated = test.value
        assert expected == calculated

    def test_CONFERENCE_CALL_CONTROL_should_serialize_to_enum(self):
        expected = RequestType.CONFERENCE_CALL_CONTROL
        calculated = RequestType['CONFERENCE_CALL_CONTROL']
        assert expected == calculated

    def test_CONFERENCE_CALL_CONTROL_should_deserialize_to_string(self):
        test = RequestType.CONFERENCE_CALL_CONTROL
        expected = "conferenceCallControl"
        calculated = test.value
        assert expected == calculated

    def test_MESSAGE_DELIVERY_should_serialize_to_enum(self):
        expected = RequestType.MESSAGE_DELIVERY
        calculated = RequestType['MESSAGE_DELIVERY']
        assert expected == calculated

    def test_MESSAGE_DELIVERY_should_deserialize_to_string(self):
        test = RequestType.MESSAGE_DELIVERY
        expected = "messageDelivery"
        calculated = test.value
        assert expected == calculated

    def test_MESSAGE_STATUS_should_serialize_to_enum(self):
        expected = RequestType.MESSAGE_STATUS
        calculated = RequestType['MESSAGE_STATUS']
        assert expected == calculated

    def test_MESSAGE_STATUS_should_deserialize_to_string(self):
        test = RequestType.MESSAGE_STATUS
        expected = "messageStatus"
        calculated = test.value
        assert expected == calculated

if __name__ == '__main__':
    unittest.main()



"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest
from datetime import datetime, date
import pytest

import freeclimb
from freeclimb.model.capabilities import Capabilities
from freeclimb.model.incoming_number_result_all_of import IncomingNumberResultAllOf
from freeclimb.model.mutable_resource_model import MutableResourceModel
globals()['Capabilities'] = Capabilities
globals()['IncomingNumberResultAllOf'] = IncomingNumberResultAllOf
globals()['MutableResourceModel'] = MutableResourceModel

from freeclimb.model.incoming_number_result import IncomingNumberResult  # noqa: E501

class TestIncomingNumberResult(unittest.TestCase):
    """IncomingNumberResult unit test stubs"""

    def setUp(self):
        self.model = IncomingNumberResult(
        )
    
    def test_uri(self):
        """Test IncomingNumberResult.uri"""
        self.model.uri = "TEST_STRING"
        assert self.model.get("uri") == "TEST_STRING"

    def test_date_created(self):
        """Test IncomingNumberResult.date_created"""
        self.model.date_created = "TEST_STRING"
        assert self.model.get("date_created") == "TEST_STRING"

    def test_date_updated(self):
        """Test IncomingNumberResult.date_updated"""
        self.model.date_updated = "TEST_STRING"
        assert self.model.get("date_updated") == "TEST_STRING"

    def test_revision(self):
        """Test IncomingNumberResult.revision"""
        self.model.revision = 1
        assert self.model.get("revision") == 1

    def test_capabilities(self):
        """Test IncomingNumberResult.capabilities"""
        object = Capabilities(sms=False, voice=False, toll_free=False, ten_dlc=False, short_code=False)
        self.model.capabilities = object
        assert self.model.get("capabilities", object)

    def test_campaign_id(self):
        """Test IncomingNumberResult.campaign_id"""
        self.model.campaign_id = "TEST_STRING"
        assert self.model.get("campaign_id") == "TEST_STRING"

    def test_phone_number_id(self):
        """Test IncomingNumberResult.phone_number_id"""
        self.model.phone_number_id = "TEST_STRING"
        assert self.model.get("phone_number_id") == "TEST_STRING"

    def test_account_id(self):
        """Test IncomingNumberResult.account_id"""
        self.model.account_id = "TEST_STRING"
        assert self.model.get("account_id") == "TEST_STRING"

    def test_application_id(self):
        """Test IncomingNumberResult.application_id"""
        self.model.application_id = "TEST_STRING"
        assert self.model.get("application_id") == "TEST_STRING"

    def test_phone_number(self):
        """Test IncomingNumberResult.phone_number"""
        self.model.phone_number = "TEST_STRING"
        assert self.model.get("phone_number") == "TEST_STRING"

    def test_alias(self):
        """Test IncomingNumberResult.alias"""
        self.model.alias = "TEST_STRING"
        assert self.model.get("alias") == "TEST_STRING"

    def test_region(self):
        """Test IncomingNumberResult.region"""
        self.model.region = "TEST_STRING"
        assert self.model.get("region") == "TEST_STRING"

    def test_country(self):
        """Test IncomingNumberResult.country"""
        self.model.country = "TEST_STRING"
        assert self.model.get("country") == "TEST_STRING"

    def test_voice_enabled(self):
        """Test IncomingNumberResult.voice_enabled"""
        self.model.voice_enabled = False
        assert self.model.get("voice_enabled") == False

    def test_sms_enabled(self):
        """Test IncomingNumberResult.sms_enabled"""
        self.model.sms_enabled = False
        assert self.model.get("sms_enabled") == False

    def test_offnet(self):
        """Test IncomingNumberResult.offnet"""
        self.model.offnet = False
        assert self.model.get("offnet") == False

if __name__ == '__main__':
    unittest.main()



"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest
from datetime import datetime, date
import pytest

import freeclimb
from freeclimb.model.account_result_all_of import AccountResultAllOf
from freeclimb.model.account_status import AccountStatus
from freeclimb.model.account_type import AccountType
from freeclimb.model.mutable_resource_model import MutableResourceModel
globals()['AccountResultAllOf'] = AccountResultAllOf
globals()['AccountStatus'] = AccountStatus
globals()['AccountType'] = AccountType
globals()['MutableResourceModel'] = MutableResourceModel

from freeclimb.model.account_result import AccountResult  # noqa: E501

class TestAccountResult(unittest.TestCase):
    """AccountResult unit test stubs"""

    def setUp(self):
        self.model = AccountResult(
        )
    
    def test_uri(self):
        """Test AccountResult.uri"""
        self.model.uri = "TEST_STRING"
        assert self.model.get("uri") == "TEST_STRING"

    def test_date_created(self):
        """Test AccountResult.date_created"""
        self.model.date_created = "TEST_STRING"
        assert self.model.get("date_created") == "TEST_STRING"

    def test_date_updated(self):
        """Test AccountResult.date_updated"""
        self.model.date_updated = "TEST_STRING"
        assert self.model.get("date_updated") == "TEST_STRING"

    def test_revision(self):
        """Test AccountResult.revision"""
        self.model.revision = 1
        assert self.model.get("revision") == 1

    def test_account_id(self):
        """Test AccountResult.account_id"""
        self.model.account_id = "TEST_STRING"
        assert self.model.get("account_id") == "TEST_STRING"

    def test_api_key(self):
        """Test AccountResult.api_key"""
        self.model.api_key = "TEST_STRING"
        assert self.model.get("api_key") == "TEST_STRING"

    def test_alias(self):
        """Test AccountResult.alias"""
        self.model.alias = "TEST_STRING"
        assert self.model.get("alias") == "TEST_STRING"

    def test_label(self):
        """Test AccountResult.label"""
        self.model.label = "TEST_STRING"
        assert self.model.get("label") == "TEST_STRING"

    def test_type(self):
        """Test AccountResult.type"""
        self.model.type = AccountType.TRIAL
        assert self.model.get("type") == AccountType.TRIAL
        self.model.type = AccountType.FULL
        assert self.model.get("type") == AccountType.FULL

    def test_status(self):
        """Test AccountResult.status"""
        self.model.status = AccountStatus.CLOSED
        assert self.model.get("status") == AccountStatus.CLOSED
        self.model.status = AccountStatus.SUSPENDED
        assert self.model.get("status") == AccountStatus.SUSPENDED
        self.model.status = AccountStatus.ACTIVE
        assert self.model.get("status") == AccountStatus.ACTIVE

    def test_subresource_uris(self):
        """Test AccountResult.subresource_uris"""
        testObject = {}
        self.model.subresource_uris = testObject
        assert self.model.get("subresource_uris") == testObject

if __name__ == '__main__':
    unittest.main()



"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest
from datetime import datetime, date
import pytest

import freeclimb

from freeclimb.model.message_status import MessageStatus  # noqa: E501

class TestMessageStatus(unittest.TestCase):
    """MessageStatus unit test stubs"""

    
    def test_NEW_should_serialize_to_enum(self):
        expected = MessageStatus.NEW
        calculated = MessageStatus['NEW']
        assert expected == calculated

    def test_NEW_should_deserialize_to_string(self):
        test = MessageStatus.NEW
        expected = "new"
        calculated = test.value
        assert expected == calculated

    def test_QUEUED_should_serialize_to_enum(self):
        expected = MessageStatus.QUEUED
        calculated = MessageStatus['QUEUED']
        assert expected == calculated

    def test_QUEUED_should_deserialize_to_string(self):
        test = MessageStatus.QUEUED
        expected = "queued"
        calculated = test.value
        assert expected == calculated

    def test_REJECTED_should_serialize_to_enum(self):
        expected = MessageStatus.REJECTED
        calculated = MessageStatus['REJECTED']
        assert expected == calculated

    def test_REJECTED_should_deserialize_to_string(self):
        test = MessageStatus.REJECTED
        expected = "rejected"
        calculated = test.value
        assert expected == calculated

    def test_SENDING_should_serialize_to_enum(self):
        expected = MessageStatus.SENDING
        calculated = MessageStatus['SENDING']
        assert expected == calculated

    def test_SENDING_should_deserialize_to_string(self):
        test = MessageStatus.SENDING
        expected = "sending"
        calculated = test.value
        assert expected == calculated

    def test_SENT_should_serialize_to_enum(self):
        expected = MessageStatus.SENT
        calculated = MessageStatus['SENT']
        assert expected == calculated

    def test_SENT_should_deserialize_to_string(self):
        test = MessageStatus.SENT
        expected = "sent"
        calculated = test.value
        assert expected == calculated

    def test_FAILED_should_serialize_to_enum(self):
        expected = MessageStatus.FAILED
        calculated = MessageStatus['FAILED']
        assert expected == calculated

    def test_FAILED_should_deserialize_to_string(self):
        test = MessageStatus.FAILED
        expected = "failed"
        calculated = test.value
        assert expected == calculated

    def test_RECEIVED_should_serialize_to_enum(self):
        expected = MessageStatus.RECEIVED
        calculated = MessageStatus['RECEIVED']
        assert expected == calculated

    def test_RECEIVED_should_deserialize_to_string(self):
        test = MessageStatus.RECEIVED
        expected = "received"
        calculated = test.value
        assert expected == calculated

    def test_UNDELIVERED_should_serialize_to_enum(self):
        expected = MessageStatus.UNDELIVERED
        calculated = MessageStatus['UNDELIVERED']
        assert expected == calculated

    def test_UNDELIVERED_should_deserialize_to_string(self):
        test = MessageStatus.UNDELIVERED
        expected = "undelivered"
        calculated = test.value
        assert expected == calculated

    def test_EXPIRED_should_serialize_to_enum(self):
        expected = MessageStatus.EXPIRED
        calculated = MessageStatus['EXPIRED']
        assert expected == calculated

    def test_EXPIRED_should_deserialize_to_string(self):
        test = MessageStatus.EXPIRED
        expected = "expired"
        calculated = test.value
        assert expected == calculated

    def test_DELETED_should_serialize_to_enum(self):
        expected = MessageStatus.DELETED
        calculated = MessageStatus['DELETED']
        assert expected == calculated

    def test_DELETED_should_deserialize_to_string(self):
        test = MessageStatus.DELETED
        expected = "deleted"
        calculated = test.value
        assert expected == calculated

    def test_UNKNOWN_should_serialize_to_enum(self):
        expected = MessageStatus.UNKNOWN
        calculated = MessageStatus['UNKNOWN']
        assert expected == calculated

    def test_UNKNOWN_should_deserialize_to_string(self):
        test = MessageStatus.UNKNOWN
        expected = "unknown"
        calculated = test.value
        assert expected == calculated

if __name__ == '__main__':
    unittest.main()



"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest
from datetime import datetime, date
import pytest

import freeclimb
from freeclimb.model.play_beep import PlayBeep
globals()['PlayBeep'] = PlayBeep

from freeclimb.model.create_conference_request import CreateConferenceRequest  # noqa: E501

class TestCreateConferenceRequest(unittest.TestCase):
    """CreateConferenceRequest unit test stubs"""

    def setUp(self):
        self.model = CreateConferenceRequest(
        )
    
    def test_alias(self):
        """Test CreateConferenceRequest.alias"""
        self.model.alias = "TEST_STRING"
        assert self.model.get("alias") == "TEST_STRING"

    def test_play_beep(self):
        """Test CreateConferenceRequest.play_beep"""
        self.model.play_beep = PlayBeep.ALWAYS
        assert self.model.get("play_beep") == PlayBeep.ALWAYS
        self.model.play_beep = PlayBeep.NEVER
        assert self.model.get("play_beep") == PlayBeep.NEVER
        self.model.play_beep = PlayBeep.ENTRY_ONLY
        assert self.model.get("play_beep") == PlayBeep.ENTRY_ONLY
        self.model.play_beep = PlayBeep.EXIT_ONLY
        assert self.model.get("play_beep") == PlayBeep.EXIT_ONLY

    def test_record(self):
        """Test CreateConferenceRequest.record"""
        self.model.record = False
        assert self.model.get("record") == False

    def test_wait_url(self):
        """Test CreateConferenceRequest.wait_url"""
        self.model.wait_url = "TEST_STRING"
        assert self.model.get("wait_url") == "TEST_STRING"

    def test_status_callback_url(self):
        """Test CreateConferenceRequest.status_callback_url"""
        self.model.status_callback_url = "TEST_STRING"
        assert self.model.get("status_callback_url") == "TEST_STRING"

if __name__ == '__main__':
    unittest.main()



"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest
from datetime import datetime, date
import pytest

import freeclimb

from freeclimb.model.make_call_request import MakeCallRequest  # noqa: E501

class TestMakeCallRequest(unittest.TestCase):
    """MakeCallRequest unit test stubs"""

    def setUp(self):
        self.model = MakeCallRequest(
            _from="",
            to="",
        )
    
    def test__from(self):
        """Test MakeCallRequest._from"""
        self.model._from = "TEST_STRING"
        assert self.model.get("_from") == "TEST_STRING"

    def test_to(self):
        """Test MakeCallRequest.to"""
        self.model.to = "TEST_STRING"
        assert self.model.get("to") == "TEST_STRING"

    def test_application_id(self):
        """Test MakeCallRequest.application_id"""
        self.model.application_id = "TEST_STRING"
        assert self.model.get("application_id") == "TEST_STRING"

    def test_send_digits(self):
        """Test MakeCallRequest.send_digits"""
        self.model.send_digits = "TEST_STRING"
        assert self.model.get("send_digits") == "TEST_STRING"

    def test_if_machine(self):
        """Test MakeCallRequest.if_machine"""
        self.model.if_machine = "TEST_STRING"
        assert self.model.get("if_machine") == "TEST_STRING"

    def test_if_machine_url(self):
        """Test MakeCallRequest.if_machine_url"""
        self.model.if_machine_url = "TEST_STRING"
        assert self.model.get("if_machine_url") == "TEST_STRING"

    def test_timeout(self):
        """Test MakeCallRequest.timeout"""
        self.model.timeout = 1
        assert self.model.get("timeout") == 1

    def test_parent_call_id(self):
        """Test MakeCallRequest.parent_call_id"""
        self.model.parent_call_id = "TEST_STRING"
        assert self.model.get("parent_call_id") == "TEST_STRING"

    def test_privacy_mode(self):
        """Test MakeCallRequest.privacy_mode"""
        self.model.privacy_mode = False
        assert self.model.get("privacy_mode") == False

    def test_call_connect_url(self):
        """Test MakeCallRequest.call_connect_url"""
        self.model.call_connect_url = "TEST_STRING"
        assert self.model.get("call_connect_url") == "TEST_STRING"

if __name__ == '__main__':
    unittest.main()



"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest
from datetime import datetime, date
import pytest

import freeclimb

from freeclimb.model.get_speech_reason import GetSpeechReason  # noqa: E501

class TestGetSpeechReason(unittest.TestCase):
    """GetSpeechReason unit test stubs"""

    
    def test_ERROR_should_serialize_to_enum(self):
        expected = GetSpeechReason.ERROR
        calculated = GetSpeechReason['ERROR']
        assert expected == calculated

    def test_ERROR_should_deserialize_to_string(self):
        test = GetSpeechReason.ERROR
        expected = "error"
        calculated = test.value
        assert expected == calculated

    def test_HANGUP_should_serialize_to_enum(self):
        expected = GetSpeechReason.HANGUP
        calculated = GetSpeechReason['HANGUP']
        assert expected == calculated

    def test_HANGUP_should_deserialize_to_string(self):
        test = GetSpeechReason.HANGUP
        expected = "hangup"
        calculated = test.value
        assert expected == calculated

    def test_DIGIT_should_serialize_to_enum(self):
        expected = GetSpeechReason.DIGIT
        calculated = GetSpeechReason['DIGIT']
        assert expected == calculated

    def test_DIGIT_should_deserialize_to_string(self):
        test = GetSpeechReason.DIGIT
        expected = "digit"
        calculated = test.value
        assert expected == calculated

    def test_NO_INPUT_should_serialize_to_enum(self):
        expected = GetSpeechReason.NO_INPUT
        calculated = GetSpeechReason['NO_INPUT']
        assert expected == calculated

    def test_NO_INPUT_should_deserialize_to_string(self):
        test = GetSpeechReason.NO_INPUT
        expected = "noInput"
        calculated = test.value
        assert expected == calculated

    def test_NO_MATCH_should_serialize_to_enum(self):
        expected = GetSpeechReason.NO_MATCH
        calculated = GetSpeechReason['NO_MATCH']
        assert expected == calculated

    def test_NO_MATCH_should_deserialize_to_string(self):
        test = GetSpeechReason.NO_MATCH
        expected = "noMatch"
        calculated = test.value
        assert expected == calculated

    def test_RECOGNITION_should_serialize_to_enum(self):
        expected = GetSpeechReason.RECOGNITION
        calculated = GetSpeechReason['RECOGNITION']
        assert expected == calculated

    def test_RECOGNITION_should_deserialize_to_string(self):
        test = GetSpeechReason.RECOGNITION
        expected = "recognition"
        calculated = test.value
        assert expected == calculated

if __name__ == '__main__':
    unittest.main()



"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest
from datetime import datetime, date
import pytest

import freeclimb

from freeclimb.model.language import Language  # noqa: E501

class TestLanguage(unittest.TestCase):
    """Language unit test stubs"""

    
    def test_CATALAN_should_serialize_to_enum(self):
        expected = Language.CATALAN
        calculated = Language['CATALAN']
        assert expected == calculated

    def test_CATALAN_should_deserialize_to_string(self):
        test = Language.CATALAN
        expected = "ca-ES"
        calculated = test.value
        assert expected == calculated

    def test_DANISH_should_serialize_to_enum(self):
        expected = Language.DANISH
        calculated = Language['DANISH']
        assert expected == calculated

    def test_DANISH_should_deserialize_to_string(self):
        test = Language.DANISH
        expected = "da-DK"
        calculated = test.value
        assert expected == calculated

    def test_GERMAN_should_serialize_to_enum(self):
        expected = Language.GERMAN
        calculated = Language['GERMAN']
        assert expected == calculated

    def test_GERMAN_should_deserialize_to_string(self):
        test = Language.GERMAN
        expected = "de-DE"
        calculated = test.value
        assert expected == calculated

    def test_ENGLISH_AU_should_serialize_to_enum(self):
        expected = Language.ENGLISH_AU
        calculated = Language['ENGLISH_AU']
        assert expected == calculated

    def test_ENGLISH_AU_should_deserialize_to_string(self):
        test = Language.ENGLISH_AU
        expected = "en-AU"
        calculated = test.value
        assert expected == calculated

    def test_ENGLISH_CA_should_serialize_to_enum(self):
        expected = Language.ENGLISH_CA
        calculated = Language['ENGLISH_CA']
        assert expected == calculated

    def test_ENGLISH_CA_should_deserialize_to_string(self):
        test = Language.ENGLISH_CA
        expected = "en-CA"
        calculated = test.value
        assert expected == calculated

    def test_ENGLISH_UK_should_serialize_to_enum(self):
        expected = Language.ENGLISH_UK
        calculated = Language['ENGLISH_UK']
        assert expected == calculated

    def test_ENGLISH_UK_should_deserialize_to_string(self):
        test = Language.ENGLISH_UK
        expected = "en-GB"
        calculated = test.value
        assert expected == calculated

    def test_ENGLISH_IN_should_serialize_to_enum(self):
        expected = Language.ENGLISH_IN
        calculated = Language['ENGLISH_IN']
        assert expected == calculated

    def test_ENGLISH_IN_should_deserialize_to_string(self):
        test = Language.ENGLISH_IN
        expected = "en-IN"
        calculated = test.value
        assert expected == calculated

    def test_ENGLISH_US_should_serialize_to_enum(self):
        expected = Language.ENGLISH_US
        calculated = Language['ENGLISH_US']
        assert expected == calculated

    def test_ENGLISH_US_should_deserialize_to_string(self):
        test = Language.ENGLISH_US
        expected = "en-US"
        calculated = test.value
        assert expected == calculated

    def test_ENGLISH_ES_should_serialize_to_enum(self):
        expected = Language.ENGLISH_ES
        calculated = Language['ENGLISH_ES']
        assert expected == calculated

    def test_ENGLISH_ES_should_deserialize_to_string(self):
        test = Language.ENGLISH_ES
        expected = "es-ES"
        calculated = test.value
        assert expected == calculated

    def test_ENGLISH_MX_should_serialize_to_enum(self):
        expected = Language.ENGLISH_MX
        calculated = Language['ENGLISH_MX']
        assert expected == calculated

    def test_ENGLISH_MX_should_deserialize_to_string(self):
        test = Language.ENGLISH_MX
        expected = "es-MX"
        calculated = test.value
        assert expected == calculated

    def test_FINNISH_should_serialize_to_enum(self):
        expected = Language.FINNISH
        calculated = Language['FINNISH']
        assert expected == calculated

    def test_FINNISH_should_deserialize_to_string(self):
        test = Language.FINNISH
        expected = "fi-FI"
        calculated = test.value
        assert expected == calculated

    def test_FRENCH_CA_should_serialize_to_enum(self):
        expected = Language.FRENCH_CA
        calculated = Language['FRENCH_CA']
        assert expected == calculated

    def test_FRENCH_CA_should_deserialize_to_string(self):
        test = Language.FRENCH_CA
        expected = "fr-CA"
        calculated = test.value
        assert expected == calculated

    def test_FRENCH_FR_should_serialize_to_enum(self):
        expected = Language.FRENCH_FR
        calculated = Language['FRENCH_FR']
        assert expected == calculated

    def test_FRENCH_FR_should_deserialize_to_string(self):
        test = Language.FRENCH_FR
        expected = "fr-FR"
        calculated = test.value
        assert expected == calculated

    def test_ITALIAN_should_serialize_to_enum(self):
        expected = Language.ITALIAN
        calculated = Language['ITALIAN']
        assert expected == calculated

    def test_ITALIAN_should_deserialize_to_string(self):
        test = Language.ITALIAN
        expected = "it-IT"
        calculated = test.value
        assert expected == calculated

    def test_JAPANESE_should_serialize_to_enum(self):
        expected = Language.JAPANESE
        calculated = Language['JAPANESE']
        assert expected == calculated

    def test_JAPANESE_should_deserialize_to_string(self):
        test = Language.JAPANESE
        expected = "ja-JP"
        calculated = test.value
        assert expected == calculated

    def test_KOREAN_should_serialize_to_enum(self):
        expected = Language.KOREAN
        calculated = Language['KOREAN']
        assert expected == calculated

    def test_KOREAN_should_deserialize_to_string(self):
        test = Language.KOREAN
        expected = "ko-KR"
        calculated = test.value
        assert expected == calculated

    def test_NORWEGIAN_should_serialize_to_enum(self):
        expected = Language.NORWEGIAN
        calculated = Language['NORWEGIAN']
        assert expected == calculated

    def test_NORWEGIAN_should_deserialize_to_string(self):
        test = Language.NORWEGIAN
        expected = "nb-NO"
        calculated = test.value
        assert expected == calculated

    def test_DUTCH_should_serialize_to_enum(self):
        expected = Language.DUTCH
        calculated = Language['DUTCH']
        assert expected == calculated

    def test_DUTCH_should_deserialize_to_string(self):
        test = Language.DUTCH
        expected = "nl-NL"
        calculated = test.value
        assert expected == calculated

    def test_POLISH_should_serialize_to_enum(self):
        expected = Language.POLISH
        calculated = Language['POLISH']
        assert expected == calculated

    def test_POLISH_should_deserialize_to_string(self):
        test = Language.POLISH
        expected = "pl-PL"
        calculated = test.value
        assert expected == calculated

    def test_PORTUGESE_BR_should_serialize_to_enum(self):
        expected = Language.PORTUGESE_BR
        calculated = Language['PORTUGESE_BR']
        assert expected == calculated

    def test_PORTUGESE_BR_should_deserialize_to_string(self):
        test = Language.PORTUGESE_BR
        expected = "pt-BR"
        calculated = test.value
        assert expected == calculated

    def test_PORTUGESE_PT_should_serialize_to_enum(self):
        expected = Language.PORTUGESE_PT
        calculated = Language['PORTUGESE_PT']
        assert expected == calculated

    def test_PORTUGESE_PT_should_deserialize_to_string(self):
        test = Language.PORTUGESE_PT
        expected = "pt-PT"
        calculated = test.value
        assert expected == calculated

    def test_RUSSIAN_should_serialize_to_enum(self):
        expected = Language.RUSSIAN
        calculated = Language['RUSSIAN']
        assert expected == calculated

    def test_RUSSIAN_should_deserialize_to_string(self):
        test = Language.RUSSIAN
        expected = "ru-RU"
        calculated = test.value
        assert expected == calculated

    def test_SWEDISH_should_serialize_to_enum(self):
        expected = Language.SWEDISH
        calculated = Language['SWEDISH']
        assert expected == calculated

    def test_SWEDISH_should_deserialize_to_string(self):
        test = Language.SWEDISH
        expected = "sv-SE"
        calculated = test.value
        assert expected == calculated

    def test_CHINESE_CN_should_serialize_to_enum(self):
        expected = Language.CHINESE_CN
        calculated = Language['CHINESE_CN']
        assert expected == calculated

    def test_CHINESE_CN_should_deserialize_to_string(self):
        test = Language.CHINESE_CN
        expected = "zh-CN"
        calculated = test.value
        assert expected == calculated

    def test_CHINESE_HK_should_serialize_to_enum(self):
        expected = Language.CHINESE_HK
        calculated = Language['CHINESE_HK']
        assert expected == calculated

    def test_CHINESE_HK_should_deserialize_to_string(self):
        test = Language.CHINESE_HK
        expected = "zh-HK"
        calculated = test.value
        assert expected == calculated

    def test_CHINESE_TW_should_serialize_to_enum(self):
        expected = Language.CHINESE_TW
        calculated = Language['CHINESE_TW']
        assert expected == calculated

    def test_CHINESE_TW_should_deserialize_to_string(self):
        test = Language.CHINESE_TW
        expected = "zh-TW"
        calculated = test.value
        assert expected == calculated

if __name__ == '__main__':
    unittest.main()
